parameter.means.names.DCM.Mplus.test: Names of parameter estimates calibrated using Mplus for fully saturated model and Q-matrix with no interaction.
Description
a vector of string containing names of calibrated parameter estimates.
Usage
parameter.means.names.DCM.Mplus.test