a numeric 1 x nitems vector of the probabilities of a correct response for each item given
that no attributes have been mastered.
r.ia.star.qmatrix
a numeric nitems x nattributes vector of the penalty probabilities for each item of
a correct response for each required attribute that has not been mastered.
qmatrix
a numeric nitems by nattributes matrix that specifies which items are required for mastery of each attribute (i.e., latent variable)
alphas
a numeric 1 x n_attributes vector with a 1 if a student has mastered an attribute and 0 otherwise.
Value
probabilities of a correct response for all items given a person's attribute profile.